/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NAnt.Core;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// Defines a customized NAnt build exception which is thrown when any error occurs during executing the server
    /// application test task in NAnt. It contains an array of causes indicating all original errors occurred when
    /// executing the test task.
    /// </summary>
    /// <author>real_vg</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public class ServerTaskException : BuildException
    {
        /// <summary>
        /// Represents the array of all original errors when executing the test task.
        /// </summary>
        private readonly Exception[] innerExceptions;

        /// <summary>
        /// Gets the array of all original errors, which cause this exception.
        /// </summary>
        /// <remarks>The original error array may be <c>null</c> or empty array.</remarks>
        /// <value>The array of all original errors causing this exception.</value>
        public Exception[] InnerExceptions
        {
            get
            {
                return innerExceptions;
            }
        }

        /// <summary>
        /// Creates a new instance of <c>ServerTaskException</c>. The string description of the exception and an array
        /// of all original causes are given.
        /// </summary>
        /// <remarks>
        /// The original cause array may be <c>null</c> or empty array.
        /// </remarks>
        /// <param name="message">The string description of the error.</param>
        /// <param name="innerExceptions">The array of all original causes of this exception.</param>
        public ServerTaskException(string message, Exception[] innerExceptions)
            : base(message, ((innerExceptions != null) && (innerExceptions.Length > 0)) ? innerExceptions[0] : null)
        {
            this.innerExceptions = innerExceptions;
        }
    }
}

